//@line 36 "/builds/slave/rel-m-beta-lnx-mb-rpk-6/mozilla-beta/sq/mobile/mobile-l10n.js"

//@line 38 "/builds/slave/rel-m-beta-lnx-mb-rpk-6/mozilla-beta/sq/mobile/mobile-l10n.js"

pref("general.useragent.locale", "sq");
